ExtrinsicParameters

Struct ExtrinsicParameters 

pub struct ExtrinsicParameters<R: RealField> { /* private fields */ }
Defines the pose of a camera in the world coordinate system.

Implementations

Source

impl<R: RealField> ExtrinsicParameters<R>

pub fn from_rotation_and_camcenter( rotation: UnitQuaternion<R>, camcenter: Point3<R>, ) -> Self

Create a new instance from a rotation and a camera center.

pub fn from_pose(pose: &Isometry3<R>) -> Self

Create a new instance from an nalgebra::Isometry3.

pub fn from_view( camcenter: &Vector3<R>, lookat: &Vector3<R>, up: &Unit<Vector3<R>>, ) -> Self

Create a new instance from a camera center, a lookat vector, and an up vector.

pub fn camcenter(&self) -> &Point3<R>

Return the camera center

pub fn pose(&self) -> &Isometry3<R>

Return the camera pose

pub fn matrix(&self) -> &SMatrix<R, 3, 4>

Return the pose as a 3x4 matrix

pub fn rotation(&self) -> &Rotation3<R>

Return the rotation part of the pose

To obtain the rotation as a quaternion, use Self::pose to obtain an Isometry3 and access the Isometry3::rotation field.

pub fn translation(&self) -> &Point3<R>

Return the translation part of the pose

pub fn forward(&self) -> Unit<Vector3<R>>

Return a unit vector aligned along our look (+Z) direction.

pub fn up(&self) -> Unit<Vector3<R>>

Return a unit vector aligned along our up (-Y) direction.

pub fn right(&self) -> Unit<Vector3<R>>

Return a unit vector aligned along our right (+X) direction.

pub fn camera_to_world<NPTS, InStorage>( &self, cam_coords: &Points<CameraFrame, R, NPTS, InStorage>, ) -> Points<WorldFrame, R, NPTS, Owned<R, NPTS, U3>>
where NPTS: Dim, InStorage: Storage<R, NPTS, U3>, DefaultAllocator: Allocator<NPTS, U3>,

Convert points in camera coordinates to world coordinates.

pub fn ray_camera_to_world<BType, NPTS, StorageCamera>( &self, camera: &RayBundle<CameraFrame, BType, R, NPTS, StorageCamera>, ) -> RayBundle<WorldFrame, BType, R, NPTS, Owned<R, NPTS, U3>>
where BType: Bundle<R>, NPTS: Dim, StorageCamera: Storage<R, NPTS, U3>, DefaultAllocator: Allocator<NPTS, U3>,

Convert rays in camera coordinates to world coordinates.

pub fn world_to_camera<NPTS, InStorage>( &self, world: &Points<WorldFrame, R, NPTS, InStorage>, ) -> Points<CameraFrame, R, NPTS, Owned<R, NPTS, U3>>
where NPTS: Dim, InStorage: Storage<R, NPTS, U3>, DefaultAllocator: Allocator<NPTS, U3>,

Convert points in world coordinates to camera coordinates.