pub struct IntrinsicParametersPerspective<R: RealField> { /* private fields */ }Expand description
A pinhole perspective camera model. Implements IntrinsicParameters.
Create an IntrinsicParametersPerspective as described for
PerspectiveParams by using .into().
Implementations
Sourceimpl<R: RealField> IntrinsicParametersPerspective<R>
impl<R: RealField> IntrinsicParametersPerspective<R>
Sourcepub fn from_normalized_3x4_matrix(p: SMatrix<R, 3, 4>) -> Result<Self, Error>
pub fn from_normalized_3x4_matrix(p: SMatrix<R, 3, 4>) -> Result<Self, Error>
Create a new instance given an intrinsic parameter matrix.
Returns an error if the intrinsic parameter matrix is not normalized or otherwise does not represent a perspective camera model.
Sourcepub fn params(&self) -> &PerspectiveParams<R>
pub fn params(&self) -> &PerspectiveParams<R>
Get intrinsic parameters