PerspectiveParams

Struct PerspectiveParams 

pub struct PerspectiveParams<R: RealField> {
    pub fx: R,
    pub fy: R,
    pub skew: R,
    pub cx: R,
    pub cy: R,
}
Parameters defining a pinhole perspective camera model.

These will be used to make the 3x4 intrinsic parameter matrix

[[fx, skew, cx, 0],
 [ 0,   fy, cy, 0],
 [ 0,    0,  1, 0]]

These parameters describe the intrinsic parameters, the transformation from camera coordinates to pixel coordinates, for a perspective camera model. For a full transformation from world coordinates to pixel coordinates, use a Camera, which can be constructed with these intinsic parameters and extrinsic parameters.

Read more about the pinhole perspective projection.

Can be converted into IntrinsicParametersPerspective via the .into() method like so:

use cam_geom::*;
let params = PerspectiveParams {
    fx: 100.0,
    fy: 100.0,
    skew: 0.0,
    cx: 640.0,
    cy: 480.0,
};
let intrinsics: IntrinsicParametersPerspective<_> = params.into();

Fields

fx: R

Horizontal focal length.

fy: R

Vertical focal length.

skew: R

Skew between horizontal and vertical axes.

cx: R

Horizontal component of the principal point.

cy: R

Vertical component of the principal point.