IntrinsicParameters

Trait IntrinsicParameters 

pub trait IntrinsicParameters<R>: Debug + Clone
where R: RealField,
{ type BundleType; // Required methods fn pixel_to_camera<IN, NPTS>( &self, pixels: &Pixels<R, NPTS, IN>, ) -> RayBundle<CameraFrame, Self::BundleType, R, NPTS, Owned<R, NPTS, U3>> where Self::BundleType: Bundle<R>, IN: Storage<R, NPTS, U2>, NPTS: Dim, DefaultAllocator: Allocator<U1, U2> + Allocator<NPTS, U2> + Allocator<NPTS, U3>; fn camera_to_pixel<IN, NPTS>( &self, camera: &Points<CameraFrame, R, NPTS, IN>, ) -> Pixels<R, NPTS, Owned<R, NPTS, U2>> where IN: Storage<R, NPTS, U3>, NPTS: Dim, DefaultAllocator: Allocator<NPTS, U2>; }
A geometric model of camera coordinates to pixels (and vice versa).

Required Associated Types

type BundleType

What type of ray bundle is returned when projecting pixels to rays.

Required Methods

fn pixel_to_camera<IN, NPTS>( &self, pixels: &Pixels<R, NPTS, IN>, ) -> RayBundle<CameraFrame, Self::BundleType, R, NPTS, Owned<R, NPTS, U3>>
where Self::BundleType: Bundle<R>, IN: Storage<R, NPTS, U2>, NPTS: Dim, DefaultAllocator: Allocator<U1, U2> + Allocator<NPTS, U2> + Allocator<NPTS, U3>,

project pixels to camera coords

fn camera_to_pixel<IN, NPTS>( &self, camera: &Points<CameraFrame, R, NPTS, IN>, ) -> Pixels<R, NPTS, Owned<R, NPTS, U2>>
where IN: Storage<R, NPTS, U3>, NPTS: Dim, DefaultAllocator: Allocator<NPTS, U2>,

project camera coords to pixel coordinates

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors