pub struct ExtrinsicParameters<R: RealField> { /* private fields */ }Expand description
Defines the pose of a camera in the world coordinate system.
Implementations
Sourceimpl<R: RealField> ExtrinsicParameters<R>
impl<R: RealField> ExtrinsicParameters<R>
Sourcepub fn from_rotation_and_camcenter(
rotation: UnitQuaternion<R>,
camcenter: Point3<R>,
) -> Self
pub fn from_rotation_and_camcenter( rotation: UnitQuaternion<R>, camcenter: Point3<R>, ) -> Self
Create a new instance from a rotation and a camera center.
Sourcepub fn from_pose(pose: &Isometry3<R>) -> Self
pub fn from_pose(pose: &Isometry3<R>) -> Self
Create a new instance from an nalgebra::Isometry3.
Sourcepub fn from_view(
camcenter: &Vector3<R>,
lookat: &Vector3<R>,
up: &Unit<Vector3<R>>,
) -> Self
pub fn from_view( camcenter: &Vector3<R>, lookat: &Vector3<R>, up: &Unit<Vector3<R>>, ) -> Self
Create a new instance from a camera center, a lookat vector, and an up vector.
Sourcepub fn rotation(&self) -> &Rotation3<R>
pub fn rotation(&self) -> &Rotation3<R>
Return the rotation part of the pose
To obtain the rotation as a quaternion, use Self::pose to obtain an Isometry3 and access the Isometry3::rotation field.
Sourcepub fn translation(&self) -> &Point3<R>
pub fn translation(&self) -> &Point3<R>
Return the translation part of the pose
Sourcepub fn forward(&self) -> Unit<Vector3<R>>
pub fn forward(&self) -> Unit<Vector3<R>>
Return a unit vector aligned along our look (+Z) direction.
Sourcepub fn right(&self) -> Unit<Vector3<R>>
pub fn right(&self) -> Unit<Vector3<R>>
Return a unit vector aligned along our right (+X) direction.
Sourcepub fn camera_to_world<NPTS, InStorage>(
&self,
cam_coords: &Points<CameraFrame, R, NPTS, InStorage>,
) -> Points<WorldFrame, R, NPTS, Owned<R, NPTS, U3>>
pub fn camera_to_world<NPTS, InStorage>( &self, cam_coords: &Points<CameraFrame, R, NPTS, InStorage>, ) -> Points<WorldFrame, R, NPTS, Owned<R, NPTS, U3>>
Convert points in camera coordinates to world coordinates.
Sourcepub fn ray_camera_to_world<BType, NPTS, StorageCamera>(
&self,
camera: &RayBundle<CameraFrame, BType, R, NPTS, StorageCamera>,
) -> RayBundle<WorldFrame, BType, R, NPTS, Owned<R, NPTS, U3>>
pub fn ray_camera_to_world<BType, NPTS, StorageCamera>( &self, camera: &RayBundle<CameraFrame, BType, R, NPTS, StorageCamera>, ) -> RayBundle<WorldFrame, BType, R, NPTS, Owned<R, NPTS, U3>>
Convert rays in camera coordinates to world coordinates.
Sourcepub fn world_to_camera<NPTS, InStorage>(
&self,
world: &Points<WorldFrame, R, NPTS, InStorage>,
) -> Points<CameraFrame, R, NPTS, Owned<R, NPTS, U3>>
pub fn world_to_camera<NPTS, InStorage>( &self, world: &Points<WorldFrame, R, NPTS, InStorage>, ) -> Points<CameraFrame, R, NPTS, Owned<R, NPTS, U3>>
Convert points in world coordinates to camera coordinates.